# Makefile for pnmxpad
# Last edited on 2004-09-20 02:10:39 by stolfi

PUBINC := /home/staff/stolfi/PUB/include
PUBLIB := /home/staff/stolfi/PUB/${PLATFORM}/lib
PUBBIN := /home/staff/stolfi/PUB/${PLATFORM}/bin

INC := /home/staff/stolfi/include
LIB := /home/staff/stolfi/${PLATFORM}/lib
BIN := /home/staff/stolfi/${PLATFORM}/bin

EXPDIR := /home/staff/stolfi/teses/luciana-2004-09-20-js/graficos

PROG := qtinfo
   
HFILES :=

CFILES :=

LIBS := \
  ${LIB}/libfftw3.a

SHELL := /bin/sh

.PHONY: \
  all clean \
  run run-single-scale run-single-pair

all: ${PROG} run
# all: ${PROG}
# all: clean ${HOFILES} ${OFILES} ${PROG}
  
MAINC := ${PROG}.c
MAKEFILE := ${PROG}.make

HOFILES := ${subst .h,.ho,${HFILES}}
OFILES := ${subst .c,.o,${CFILES}}

CC := gcc \
  -Wall  -Wpointer-arith -Wmissing-prototypes

CFLAGS :=   -O -g
LDFLAGS :=       
IFLAGS :=   -I. -I${INC} -I${PUBINC}

%.o: %.c
	${CC} ${CFLAGS} ${IFLAGS} $*.c
  
%.ho: %.h
	${CC} ${CFLAGS} ${IFLAGS} -o $*.ho -c -x c $*.h \
          || /bin/rm -f $*.ho
  
# Special rule for ${PROG}.o:

${PROG}.o: ${MAINC} ${HOFILES} \
              ${INC}/fftw3.h
	${CC} ${CFLAGS} ${IFLAGS} -o ${PROG}.o -c ${MAINC}
 
${PROG}: ${OFILES} ${PROG}.o ${LIBS}
	${CC} ${LDFLAGS} -o $@ ${PROG}.o ${OFILES} ${LIBS} -lm

clean:
	-/bin/rm -f *.o *.ho *.a *~ core ${PROG} 

# Dependencies for ".o" files:
  
######################################################################
# Running the program

# List of pairs:
PAIRLIST := ../data/pairs.txt

# Number of base pairs in scale 0 (multi-scale analysis):
NBASES_MS := 480

# Number of base pairs in scale 0 (single-scale analysis):
NBASES_US := 495

# Sampling scales (0 = original):
SCALES := 0 1 2 3 4 5
# SCALES := 0
# SCALES := 1

run: run-multiscale run-uniscale

run-multiscale: 
	for sc in ${SCALES} ; do \
          ${MAKE} -f ${MAKEFILE} \
            NBASES=${NBASES_MS} XSIZE=0.50 SCALE=$$sc \
            run-single-scale ; \
        done

run-uniscale: 
	${MAKE} -f ${MAKEFILE} \
          NBASES=${NBASES_US} XSIZE=1.0 SCALE=0 \
          run-single-scale
        
######################################################################
# Recursive make - caller must define ${SCALE},${NBASES},${XSIZE}

SCALE := SCALE.IS.UNDEFINED
ifneq "${SCALE}" "SCALE.IS.UNDEFINED"
NBASES := NBASES.IS.UNDEFINED
ifneq "${NBASES}" "NBASES.IS.UNDEFINED"
XSIZE := XSIZE.IS.UNDEFINED
ifneq "${XSIZE}" "XSIZE.IS.UNDEFINED"
       
DATADIR := ../data
RSLTDIR := ../rslt
PLOTDIR := ../plot

# Where to find the files with power spectra:
INDIR := ${RSLTDIR}

# Prefixes of sample files:
PAIRLISTFILE := ../data/pairs.txt
PAIRS := ${shell cat ${PAIRLISTFILE}}
APAIR := ${word 1,${PAIRS}}
        
OTFILE := ${RSLTDIR}/s${SCALE}-${NBASES}-INFO.txt

MKDKFIG := ${PLOTDIR}/s${SCALE}-${NBASES}-MD.eps
INFOFIG := ${PLOTDIR}/s${SCALE}-${NBASES}-INFO.eps

EPSFILES := \
  ${MKDKFIG} \
  ${INFOFIG}

run-single-scale: ${OTFILE} ${EPSFILES} export

${OTFILE}: ${PAIRLISTFILE} \
            ${INDIR}/s${SCALE}-${NBASES}-${APAIR}.txt \
            ${PROG} ${MAKEFILE}
	./${PROG} \
            ${INDIR} ${NBASES} ${SCALE} \
          < ${PAIRLISTFILE} \
          > ${OTFILE}

${MKDKFIG}: ${OTFILE} plot-mkdk ${MAKEFILE}
	./plot-mkdk ${RSLTDIR} ${NBASES} ${SCALE} ${XSIZE} \
          > ${MKDKFIG}
	gv ${MKDKFIG}

${INFOFIG}: ${OTFILE} plot-info ${MAKEFILE}
	./plot-info ${RSLTDIR} ${NBASES} ${SCALE} ${XSIZE} \
          > ${INFOFIG}
	gv ${INFOFIG}
        
export: ${OTFILE} ${MKDKFIG} ${INFOFIG}  ${MAKEFILE}
	cp -av ${OTFILE} ${MKDKFIG} ${INFOFIG} ${EXPDIR}

endif
endif
endif
# End make ${SCALE},${NBASES},${XSIZE}
######################################################################
